import React from "react";
import { render, screen, waitFor, act } from "@testing-library/react";
import userEvent from "@testing-library/user-event";
import { Login } from ".";

describe("ログイン機能", () => {
  test("ログインに成功", async () => {
    jest
      .spyOn(window, "fetch")
      .mockResolvedValue({ json: () => ({ token: "123" }) });
    render(<Login />);
    const emailInput = screen.getByTestId("emailInput");
    const passwordInput = screen.getByTestId("passwordInput");
    const submitButton = screen.getByTestId("submitButton");
    const successText = screen.getByTestId("successText");

    expect(successText).toHaveTextContent("");

    await act(async () => {
      userEvent.type(emailInput, "eve.holt@reqres.in");
    });

    await act(async () => {
      userEvent.type(passwordInput, "cityslicka");
    });

    await act(async () => {
      userEvent.click(submitButton);
    });

    await waitFor(() => {
      expect(successText).toHaveTextContent("ログイン成功");
    });
  });

  test("ログインに失敗", async () => {
    jest
      .spyOn(window, "fetch")
      .mockResolvedValue({ json: () => ({}) });
    render(<Login />);
    const emailInput = screen.getByTestId("emailInput");
    const passwordInput = screen.getByTestId("passwordInput");
    const submitButton = screen.getByTestId("submitButton");
    const successText = screen.getByTestId("successText");

    expect(successText).toHaveTextContent("");

    await act(async () => {
      userEvent.type(emailInput, "eve.holt@reqres.in");
    });

    await act(async () => {
      userEvent.type(passwordInput, "cityslicka");
    });

    await act(async () => {
      userEvent.click(submitButton);
    });

    await waitFor(() => {
      expect(successText).toHaveTextContent("ログイン失敗");
    });
  });
})

